/* ****** BEGIN LICENSE BLOCK *****
Version: MPL 1.1/GPL 2.0/LGPL 2.1

The contents of this file are subject to the Mozilla Public License Version 
1.1 (the "License"); you may not use this file except in compliance with 
the License. You may obtain a copy of the License at 
http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
for the specific language governing rights and limitations under the
License.

The Original Code is Checky.

The Initial Developer of the Original Code is
Joachim Schreiber (yo@yos.biz).
Portions created by the Initial Developer are Copyright (C) 2002
the Initial Developer. All Rights Reserved.

Contributor(s):

Alternatively, the contents of this file may be used under the terms of
either the GNU General Public License Version 2 or later (the "GPL"), or
the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
in which case the provisions of the GPL or the LGPL are applicable instead
of those above. If you wish to allow use of your version of this file only
under the terms of either the GPL or the LGPL, and not to allow others to
use your version of this file under the terms of the MPL, indicate your
decision by deleting the provisions above and replace them with the notice
and other provisions required by the GPL or the LGPL. If you do not delete
the provisions above, a recipient may use your version of this file under
the terms of any one of the MPL, the GPL or the LGPL.

The Checky plug-in is a simple Interface for Web Content and 
Web Page Developers to free and commercial Validator and Checker 
Services on the Web. We do not provide any support or guarantee. 
Any rights not expressly granted herein are reserved by their owners. 
Please visit the Web Sites of the Service owners for more informations 
about terms of usage before using Checky the first. Hyperlinks are 
located at http://checky.mozdev.org/services.html

***** END LICENSE BLOCK ***** */


/* CHECKY INIT */

function checkyInit(){

	window.removeEventListener("load",checkyInit,true);

	try{
	    dump( pref.getIntPref("checky.global.appearType") );
	}
	catch(e){

		/* Global */

	    //appearance to Tab
	    pref.setIntPref("checky.global.appearType", 0);


		/* Agent */

	    pref.setBoolPref("checky.agent.w3c.markup", true);
	    pref.setBoolPref("checky.agent.w3c.css", false);
	    pref.setBoolPref("checky.agent.w3c.rdf", false);
	    pref.setBoolPref("checky.agent.w3c.link", false);
	    pref.setBoolPref("checky.agent.w3c.tidy", false);
	    pref.setBoolPref("checky.agent.wdg.html", false);
	    pref.setBoolPref("checky.agent.wdg.css", false);
	    pref.setBoolPref("checky.agent.wdg.link", false);
	    pref.setBoolPref("checky.agent.thing.page", false);
	    pref.setBoolPref("checky.agent.del.lynx", false);
	    pref.setBoolPref("checky.agent.del.pur", false);
	    pref.setBoolPref("checky.agent.del.header", false);
	    pref.setBoolPref("checky.agent.bobby", false);
	    pref.setBoolPref("checky.agent.taw", false);
	    pref.setBoolPref("checky.agent.piat2", false);
	    pref.setBoolPref("checky.agent.piat22", false);
	    pref.setBoolPref("checky.agent.red", false);
	    pref.setBoolPref("checky.agent.mark", false);


		/* W3C Markup */

	    //charset
	    pref.setIntPref("checky.w3c.markup.charset", 0);

	    //doctype
	    pref.setIntPref("checky.w3c.markup.doctype", 0);
		
		//Show Source
	    pref.setBoolPref("checky.w3c.markup.ss", false);

		//Show Parse Tree
	    pref.setBoolPref("checky.w3c.markup.sp", false);

		//Show Outline
	    pref.setBoolPref("checky.w3c.markup.outline", false);

		//...exclude attributes
	    pref.setBoolPref("checky.w3c.markup.noatt", false);

		//Validate error pages
	    pref.setBoolPref("checky.w3c.markup.No200", false);

		//Verbose Output
	    pref.setBoolPref("checky.w3c.markup.verbose", true);



		/* W3C CSS */

	    pref.setIntPref("checky.w3c.css.warning", 1);
	    pref.setIntPref("checky.w3c.css.profile", 2);


		/* W3C RDF */

	    pref.setIntPref("checky.w3c.rdf.TRIPLES_AND_GRAPH", 0);

	    pref.setBoolPref("checky.w3c.rdf.SAVE_DOT_FILE", false);

	    pref.setBoolPref("checky.w3c.rdf.NTRIPLES", false);
	    pref.setBoolPref("checky.w3c.rdf.EMBEDDED_RDF", false);
	    pref.setBoolPref("checky.w3c.rdf.SAVE_RDF", false);
	    pref.setBoolPref("checky.w3c.rdf.ANON_NODES_EMPTY", false);

	    pref.setIntPref("checky.w3c.rdf.NODE_COLOR", 0);
	    pref.setIntPref("checky.w3c.rdf.NODE_TEXT_COLOR", 0);
	    pref.setIntPref("checky.w3c.rdf.EDGE_COLOR", 0);
	    pref.setIntPref("checky.w3c.rdf.EDGE_TEXT_COLOR", 0);

	    pref.setIntPref("checky.w3c.rdf.FONT_SIZE", 0);
	    pref.setIntPref("checky.w3c.rdf.ORIENTATION", 0);
	    pref.setIntPref("checky.w3c.rdf.FORMAT", 0);


		/* W3C Link */

	    pref.setBoolPref("checky.w3c.link.summary", false);
	    pref.setBoolPref("checky.w3c.link.hide_redirects", false);
	    pref.setBoolPref("checky.w3c.link.no_accept_language", false);
	    pref.setBoolPref("checky.w3c.link.cookie", false);
	    pref.setBoolPref("checky.w3c.link.recursive", false);

	    pref.setIntPref("checky.w3c.link.hide_type", 0);

	    pref.setCharPref("checky.w3c.link.depth", "");


		/* W3C Tidy */

	    pref.setBoolPref("checky.w3c.tidy.indent", false);


		/* WDG HTML */

	    pref.setBoolPref("checky.wdg.html.warnings", true);
	    pref.setBoolPref("checky.wdg.html.input", true);
	    pref.setBoolPref("checky.wdg.html.spider", false);
	    pref.setBoolPref("checky.wdg.html.hidevalid", false);

		/* WDG CSS */

	    pref.setBoolPref("checky.wdg.css.warnings", true);
	    pref.setBoolPref("checky.wdg.css.input", true);

		/* WDG Link */

	    pref.setCharPref("checky.wdg.link.date", "2000-01-01");
	    pref.setIntPref("checky.wdg.link.type", 0);

		/* WebThing Page */

	    pref.setIntPref("checky.thing.page.wcag", 0);
	    pref.setIntPref("checky.thing.page.fmt", 0);
	    pref.setIntPref("checky.thing.page.xsl", 0);
	    pref.setIntPref("checky.thing.page.parse", 3);


		/* Delorie Purifier */

	    pref.setIntPref("checky.del.pur.purity", 3);
	    pref.setBoolPref("checky.del.pur.text", false);


		/* Bobby */

	    pref.setIntPref("checky.bobby.gl", 2);
	    pref.setBoolPref("checky.bobby.text", true);
	    pref.setBoolPref("checky.bobby.line", true);
	    pref.setBoolPref("checky.bobby.an_errs", true);
	    pref.setIntPref("checky.bobby.stealth", 0);


		/* Taw */

	    pref.setIntPref("checky.taw.tipo", 0);
	    pref.setBoolPref("checky.taw.i", false);


		/* Wave 201 */

	    pref.setBoolPref("checky.piat2.usestyle", true);
	    pref.setBoolPref("checky.piat2.is_noframes", false);

		/* Wave 22 */

	    pref.setBoolPref("checky.piat22.usestyle", true);
	    pref.setBoolPref("checky.piat22.is_noframes", false);

		/* Redland RSS */

	    pref.setIntPref("checky.red.box", 1);

	}

}


